/// <reference types="node" />
import { Extension, onChangePayload, onLoadDocumentPayload } from '@hocuspocus/server';
export interface DatabaseConfiguration {
    /**
     * Pass a Promise to retrieve updates from your database. The Promise should resolve to
     * an array of items with Y.js-compatible binary data.
     */
    fetchUpdates: ({ documentName }: {
        documentName: string;
    }) => Promise<Uint8Array[]>;
    /**
     * Pass a function to store updates in your database.
     */
    storeUpdate: ({ update, documentName }: {
        update: Buffer;
        documentName: string;
    }) => void;
}
export declare class Database implements Extension {
    /**
     * Default configuration
     */
    configuration: DatabaseConfiguration;
    /**
     * Constructor
     */
    constructor(configuration: Partial<DatabaseConfiguration>);
    /**
     * Get stored data from the database.
     */
    onLoadDocument({ document, documentName }: onLoadDocumentPayload): Promise<any>;
    /**
     * Store new updates in the database.
     */
    onChange({ document, documentName }: onChangePayload): Promise<void>;
}
